@@ -9,7 +9,7 @@ use SOAP::Lite; # +trace => 'debug';
 use warnings;
 use strict;
 
-$VMware::API::LabManager::VERSION = '2.10';
+$VMware::API::LabManager::VERSION = '2.11';
 
 ### External methods
 
@@ -1542,7 +1542,7 @@ Code to checkout, deploy, undeploy and delete a configuration:
 
  	use VMware::API::LabManager;
 
-    my $labman = new VMware::LabManager ( $username, $password, $server, $orgname, $workspace );
+    my $labman = new VMware::API::LabManager ( $username, $password, $server, $orgname, $workspace );
 
  	# Get the id of the config you are going to check out
  	my $config = $labman->GetSingleConfigurationByName("myConfigName");
@@ -2856,11 +2856,11 @@ Boy would this make my life easier to debug issues quickly.
 
 =head1 VERSION
 
-	VMware::API::LabManager v2.10 (2014/04/30)
+	VMware::API::LabManager v2.11 (2015/06/08)
 
 =head1 COPYRIGHT
 
-    (c) 2004-2014, Phillip Pollard <bennie@cpan.org>
+    (c) 2004-2015, Phillip Pollard <bennie@cpan.org>
 
 =head1 LICENSE
 
